# To change this license header, choose License Headers in Project Properties.
# To change this template file, choose Tools | Templates
# and open the template in the editor.

import json
import re
from os.path import expanduser
import os
import urllib
import tempfile

import download_utils
import printer

__author__="UShareSoft"


def extract_id(uri):
        elements = uri.split("/");
        return elements[len(elements) - 1];                

def check_json_syntax(file):
        try:
                printer.out("Validating the template file ["+file+"] ...")
                json_data=open(file)
                data = json.load(json_data)
                json_data.close()
                printer.out("Syntax of template file ["+file+"] is ok", printer.OK)
                return data
        except ValueError as e:
                printer.out("Syntax of template file ["+file+"] FAILED", printer.ERROR)
                printer.out("JSON parsing error: "+str(e))
                return
        except IOError as e:
                printer.out("File error: "+str(e), printer.ERROR)
                return

def query_yes_no(question, default="yes"):
        """Ask a yes/no question via raw_input() and return their answer.

        "question" is a string that is presented to the user.
        "default" is the presumed answer if the user just hits <Enter>.
            It must be "yes" (the default), "no" or None (meaning
            an answer is required of the user).

        The "answer" return value is one of "yes" or "no".
        """
        valid = {"yes":True,   "y":True,  "ye":True,
                 "no":False,     "n":False}
        if default == None:
                prompt = " [y/n] "
        elif default == "yes":
                prompt = " [Y/n] "
        elif default == "no":
                prompt = " [y/N] "
        else:
                raise ValueError("invalid default answer: '%s'" % default)

        while True:
                printer.out(question + prompt)
                choice = raw_input().lower()
                if default is not None and choice == '':
                        return valid[default]
                elif choice in valid:
                        return valid[choice]
                else:
                        printer.out("Please respond with 'yes' or 'no' "\
                                     "(or 'y' or 'n').\n")
                             
                             
def remove_special_chars(string):
        return (re.sub('[-]', '_', string)).lower()



def order_list_object_by(objects, attribute):
        if type(attribute) is str:
                return sorted(objects, key=lambda x: getattr(x, attribute).lower(), reverse=False)
        return objects
    
def get_uforge_url_from_ws_url(ws_url):
        if ws_url[-1:]!='/':
                return ws_url.rpartition('/')[0]
        else:
                return ws_url[:-1].rpartition('/')[0]

def get_home_dir():
        return expanduser("~")

def get_remote_regex():
        return (r'^(?:http|ftp)s?://' # http:// or https://
                r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
                r'localhost|' #localhost...
                r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' # ...or ip
                r'(?::\d+)?' # optional port
                r'(?:/?|[/?]\S+)$')

def get_file(uri, dest_file_name=None):
        try:
                regexp = re.compile(get_remote_regex(), re.IGNORECASE)
                if regexp.search(uri) is not None:
                        dlUtils = download_utils.Download(uri, dest_file_name)
                        try:
                            dlUtils.start()
                        except Exception, e:
                            return 2
                else:
                        dest_file_name, headers = urllib.urlretrieve(uri)
                return dest_file_name
        except Exception, e:
                print("error downloading "+uri+": "+ str(e))
                return
            
def remove_URI_forbidden_char(string):
        chars= ' '
        return re.sub(chars, '_', string)

def is_superviser_mode(userName):
        if "\\" in userName:
                return True
        else:
                return False

def get_target_username(userName):
    if "\\" in userName:
        return userName.split('\\')[1]


__author__="UShareSoft"

def print_graph(values):
        max=0
        for v in values:
                if len(v)>max:
                        max=len(v)
        for v in values:
                value = int(values[v])
                if len(v)<max:
                        newV=v+(" " * int(max-len(v)))
                        if value!=-1:
                                print newV, value*'|'+'-'*int(50-value)
                        else:
                                print newV,20*'-'+"UNLIMITED"+21*'-'
                else:
                        if value!=-1:
                                print v, value*'|'+'-'*int(50-value)
                        else:
                                print v,20*'-'+"UNLIMITED"+21*'-'



# To change this license header, choose License Headers in Project Properties.
# To change this template file, choose Tools | Templates
# and open the template in the editor.

__author__="UShareSoft"

import urllib2
import traceback
from hurry.filesize import size
from progressbar import AnimatedMarker, Bar, BouncingBar, Counter, ETA, \
    FileTransferSpeed, FormatLabel, Percentage, \
    ProgressBar, ReverseBar, RotatingMarker, \
    SimpleProgress, Timer
import printer

class Download():
        
        def __init__(self, url, dest_file_name):
                self.url = url
                self.dest_file_name = dest_file_name

        def chunk_read(self, response, file, chunk_size=8192, report_hook=False):
                # inspired by http://stackoverflow.com/questions/2028517/python-urllib2-progress-hook
                total_size = response.info().getheader('Content-Length').strip()
                total_size = int(total_size)
                bytes = 0

                printer.out("Ready to download "+size(total_size), printer.INFO)

                #widgets = ['Status: ', Percentage(), ' ', Bar('>'), ' ', ETA(), ' ', FileTransferSpeed()]
                widgets = ['Status: ', Percentage(), ' ', Bar('>'), ' ', ETA()]
                self.pbar = ProgressBar(widgets=widgets, maxval=100).start()

                while True:
                        chunk = response.read(chunk_size)
                        file.write(chunk)
                        bytes += len(chunk)
                        if not chunk:
                                break
                        if report_hook:
                                self.progress_update((bytes/chunk_size), chunk_size, total_size)

                return bytes

        def start(self):
                file = open(self.dest_file_name, 'wb')
                try:
                        response = urllib2.urlopen(self.url)
                        bytes = self.chunk_read(response, file, report_hook=True)
                        self.progress_finish()
                except urllib2.HTTPError as e:
                        printer.out("Error getting URL: "+self.url, printer.ERROR)
                        raise e



        def progress_update(self, count, blockSize, totalSize):
                percent=None
                if totalSize-blockSize<=0:
                        percent=50
                else:
                        if totalSize-(count*blockSize)>=0:
                                percent = int(count*blockSize*100/totalSize)
                if percent is not None:
                        self.pbar.update(percent)
                
        def progress_finish(self):
                self.pbar.finish()


from setuptools import setup,find_packages
import os
import sys

# Declare your packages' dependencies here, for eg:
requires=[
            'cmd2==0.6.7',
            'argparse',
            'progressbar==2.3',
            'termcolor==1.1.0',
            'hurry.filesize==0.9',
         ]

if os.name != "nt":
    if not "linux" in sys.platform:
        #mac os
        requires.append('readline')
else:   #On Windows
    requires.append('pyreadline==2.0')

                    
setup (
  install_requires=requires,
  
  name = 'ussclicore',
  version = '1.0.5',
  description='UShareSoft cli core module',
  #long_description='',
  packages = find_packages(),
  author = 'Joris Bremond',
  author_email = 'joris.bremond@usharesoft.com',
  license="Apache License 2.0",
  #url = '',
  classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Natural Language :: English',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ),
       
  
  #long_description= 'Long description of the package',
  
)
